% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/DataFrame.R, R/generics.R, R/group.R
\docType{methods}
\name{gapplyCollect}
\alias{gapplyCollect}
\alias{gapplyCollect,GroupedData-method}
\alias{gapplyCollect,SparkDataFrame-method}
\title{gapplyCollect}
\usage{
\S4method{gapplyCollect}{SparkDataFrame}(x, cols, func)

gapplyCollect(x, ...)

\S4method{gapplyCollect}{GroupedData}(x, func)
}
\arguments{
\item{x}{a SparkDataFrame or GroupedData.}

\item{cols}{grouping columns.}

\item{func}{a function to be applied to each group partition specified by grouping
column of the SparkDataFrame. The function \code{func} takes as argument
a key - grouping columns and a data frame - a local R data.frame.
The output of \code{func} is a local R data.frame.}

\item{...}{additional argument(s) passed to the method.}
}
\value{
A data.frame.
}
\description{
Groups the SparkDataFrame using the specified columns, applies the R function to each
group and collects the result back to R as data.frame.

gapplyCollect
}
\note{
gapplyCollect(SparkDataFrame) since 2.0.0

gapplyCollect(GroupedData) since 2.0.0
}
\examples{
\dontrun{
Computes the arithmetic mean of the second column by grouping
on the first and third columns. Output the grouping values and the average.

df <- createDataFrame (
list(list(1L, 1, "1", 0.1), list(1L, 2, "1", 0.2), list(3L, 3, "3", 0.3)),
  c("a", "b", "c", "d"))

result <- gapplyCollect(
  df,
  c("a", "c"),
  function(key, x) {
    y <- data.frame(key, mean(x$b), stringsAsFactors = FALSE)
    colnames(y) <- c("key_a", "key_c", "mean_b")
    y
  })

We can also group the data and afterwards call gapply on GroupedData.
For Example:
gdf <- group_by(df, "a", "c")
result <- gapplyCollect(
  gdf,
  function(key, x) {
    y <- data.frame(key, mean(x$b), stringsAsFactors = FALSE)
    colnames(y) <- c("key_a", "key_c", "mean_b")
    y
  })

Result
------
key_a key_c mean_b
3 3 3.0
1 1 1.5

Fits linear models on iris dataset by grouping on the 'Species' column and
using 'Sepal_Length' as a target variable, 'Sepal_Width', 'Petal_Length'
and 'Petal_Width' as training features.

df <- createDataFrame (iris)
result <- gapplyCollect(
  df,
  df$"Species",
  function(key, x) {
    m <- suppressWarnings(lm(Sepal_Length ~
    Sepal_Width + Petal_Length + Petal_Width, x))
    data.frame(t(coef(m)))
  })

Result
---------
Model  X.Intercept.  Sepal_Width  Petal_Length  Petal_Width
1        0.699883    0.3303370    0.9455356    -0.1697527
2        1.895540    0.3868576    0.9083370    -0.6792238
3        2.351890    0.6548350    0.2375602     0.2521257

}
}
\seealso{
\link{gapply}

Other SparkDataFrame functions: \code{\link{$}},
  \code{\link{$,SparkDataFrame-method}}, \code{\link{$<-}},
  \code{\link{$<-,SparkDataFrame-method}},
  \code{\link{select}}, \code{\link{select}},
  \code{\link{select,SparkDataFrame,Column-method}},
  \code{\link{select,SparkDataFrame,character-method}},
  \code{\link{select,SparkDataFrame,list-method}};
  \code{\link{SparkDataFrame-class}}; \code{\link{[}},
  \code{\link{[,SparkDataFrame-method}}, \code{\link{[[}},
  \code{\link{[[,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{[[<-}},
  \code{\link{[[<-,SparkDataFrame,numericOrcharacter-method}},
  \code{\link{subset}}, \code{\link{subset}},
  \code{\link{subset,SparkDataFrame-method}};
  \code{\link{agg}}, \code{\link{agg}}, \code{\link{agg}},
  \code{\link{agg,GroupedData-method}},
  \code{\link{agg,SparkDataFrame-method}},
  \code{\link{summarize}}, \code{\link{summarize}},
  \code{\link{summarize}},
  \code{\link{summarize,GroupedData-method}},
  \code{\link{summarize,SparkDataFrame-method}};
  \code{\link{arrange}}, \code{\link{arrange}},
  \code{\link{arrange}},
  \code{\link{arrange,SparkDataFrame,Column-method}},
  \code{\link{arrange,SparkDataFrame,character-method}},
  \code{\link{orderBy,SparkDataFrame,characterOrColumn-method}};
  \code{\link{as.data.frame}},
  \code{\link{as.data.frame,SparkDataFrame-method}};
  \code{\link{attach}},
  \code{\link{attach,SparkDataFrame-method}};
  \code{\link{cache}}, \code{\link{cache}},
  \code{\link{cache,SparkDataFrame-method}};
  \code{\link{coalesce}}, \code{\link{coalesce}},
  \code{\link{coalesce}},
  \code{\link{coalesce,Column-method}},
  \code{\link{coalesce,SparkDataFrame-method}};
  \code{\link{collect}}, \code{\link{collect}},
  \code{\link{collect,SparkDataFrame-method}};
  \code{\link{colnames}}, \code{\link{colnames}},
  \code{\link{colnames,SparkDataFrame-method}},
  \code{\link{colnames<-}}, \code{\link{colnames<-}},
  \code{\link{colnames<-,SparkDataFrame-method}},
  \code{\link{columns}}, \code{\link{columns}},
  \code{\link{columns,SparkDataFrame-method}},
  \code{\link{names}},
  \code{\link{names,SparkDataFrame-method}},
  \code{\link{names<-}},
  \code{\link{names<-,SparkDataFrame-method}};
  \code{\link{coltypes}}, \code{\link{coltypes}},
  \code{\link{coltypes,SparkDataFrame-method}},
  \code{\link{coltypes<-}}, \code{\link{coltypes<-}},
  \code{\link{coltypes<-,SparkDataFrame,character-method}};
  \code{\link{count,SparkDataFrame-method}},
  \code{\link{nrow}}, \code{\link{nrow}},
  \code{\link{nrow,SparkDataFrame-method}};
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView}},
  \code{\link{createOrReplaceTempView,SparkDataFrame,character-method}};
  \code{\link{crossJoin}},
  \code{\link{crossJoin,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{dapplyCollect}}, \code{\link{dapplyCollect}},
  \code{\link{dapplyCollect,SparkDataFrame,function-method}};
  \code{\link{dapply}}, \code{\link{dapply}},
  \code{\link{dapply,SparkDataFrame,function,structType-method}};
  \code{\link{describe}}, \code{\link{describe}},
  \code{\link{describe}},
  \code{\link{describe,SparkDataFrame,ANY-method}},
  \code{\link{describe,SparkDataFrame,character-method}},
  \code{\link{describe,SparkDataFrame-method}},
  \code{\link{summary}}, \code{\link{summary}},
  \code{\link{summary,SparkDataFrame-method}};
  \code{\link{dim}},
  \code{\link{dim,SparkDataFrame-method}};
  \code{\link{distinct}}, \code{\link{distinct}},
  \code{\link{distinct,SparkDataFrame-method}},
  \code{\link{unique}},
  \code{\link{unique,SparkDataFrame-method}};
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates}},
  \code{\link{dropDuplicates,SparkDataFrame-method}};
  \code{\link{dropna}}, \code{\link{dropna}},
  \code{\link{dropna,SparkDataFrame-method}},
  \code{\link{fillna}}, \code{\link{fillna}},
  \code{\link{fillna,SparkDataFrame-method}},
  \code{\link{na.omit}}, \code{\link{na.omit}},
  \code{\link{na.omit,SparkDataFrame-method}};
  \code{\link{drop}}, \code{\link{drop}},
  \code{\link{drop}}, \code{\link{drop,ANY-method}},
  \code{\link{drop,SparkDataFrame-method}};
  \code{\link{dtypes}}, \code{\link{dtypes}},
  \code{\link{dtypes,SparkDataFrame-method}};
  \code{\link{except}}, \code{\link{except}},
  \code{\link{except,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{explain}}, \code{\link{explain}},
  \code{\link{explain,SparkDataFrame-method}};
  \code{\link{filter}}, \code{\link{filter}},
  \code{\link{filter,SparkDataFrame,characterOrColumn-method}},
  \code{\link{where}}, \code{\link{where}},
  \code{\link{where,SparkDataFrame,characterOrColumn-method}};
  \code{\link{first}}, \code{\link{first}},
  \code{\link{first}},
  \code{\link{first,SparkDataFrame-method}},
  \code{\link{first,characterOrColumn-method}};
  \code{\link{gapply}}, \code{\link{gapply}},
  \code{\link{gapply}},
  \code{\link{gapply,GroupedData-method}},
  \code{\link{gapply,SparkDataFrame-method}};
  \code{\link{getNumPartitions}},
  \code{\link{getNumPartitions,SparkDataFrame-method}};
  \code{\link{groupBy}}, \code{\link{groupBy}},
  \code{\link{groupBy,SparkDataFrame-method}},
  \code{\link{group_by}}, \code{\link{group_by}},
  \code{\link{group_by,SparkDataFrame-method}};
  \code{\link{head}},
  \code{\link{head,SparkDataFrame-method}};
  \code{\link{histogram}},
  \code{\link{histogram,SparkDataFrame,characterOrColumn-method}};
  \code{\link{insertInto}}, \code{\link{insertInto}},
  \code{\link{insertInto,SparkDataFrame,character-method}};
  \code{\link{intersect}}, \code{\link{intersect}},
  \code{\link{intersect,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{isLocal}}, \code{\link{isLocal}},
  \code{\link{isLocal,SparkDataFrame-method}};
  \code{\link{join}},
  \code{\link{join,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{limit}}, \code{\link{limit}},
  \code{\link{limit,SparkDataFrame,numeric-method}};
  \code{\link{merge}}, \code{\link{merge}},
  \code{\link{merge,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{mutate}}, \code{\link{mutate}},
  \code{\link{mutate,SparkDataFrame-method}},
  \code{\link{transform}}, \code{\link{transform}},
  \code{\link{transform,SparkDataFrame-method}};
  \code{\link{ncol}},
  \code{\link{ncol,SparkDataFrame-method}};
  \code{\link{persist}}, \code{\link{persist}},
  \code{\link{persist,SparkDataFrame,character-method}};
  \code{\link{printSchema}}, \code{\link{printSchema}},
  \code{\link{printSchema,SparkDataFrame-method}};
  \code{\link{randomSplit}}, \code{\link{randomSplit}},
  \code{\link{randomSplit,SparkDataFrame,numeric-method}};
  \code{\link{rbind}}, \code{\link{rbind}},
  \code{\link{rbind,SparkDataFrame-method}};
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable}},
  \code{\link{registerTempTable,SparkDataFrame,character-method}};
  \code{\link{rename}}, \code{\link{rename}},
  \code{\link{rename,SparkDataFrame-method}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed}},
  \code{\link{withColumnRenamed,SparkDataFrame,character,character-method}};
  \code{\link{repartition}}, \code{\link{repartition}},
  \code{\link{repartition,SparkDataFrame-method}};
  \code{\link{sample}}, \code{\link{sample}},
  \code{\link{sample,SparkDataFrame,logical,numeric-method}},
  \code{\link{sample_frac}}, \code{\link{sample_frac}},
  \code{\link{sample_frac,SparkDataFrame,logical,numeric-method}};
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile}},
  \code{\link{saveAsParquetFile,SparkDataFrame,character-method}},
  \code{\link{write.parquet}}, \code{\link{write.parquet}},
  \code{\link{write.parquet,SparkDataFrame,character-method}};
  \code{\link{saveAsTable}}, \code{\link{saveAsTable}},
  \code{\link{saveAsTable,SparkDataFrame,character-method}};
  \code{\link{saveDF}}, \code{\link{saveDF}},
  \code{\link{saveDF,SparkDataFrame,character-method}},
  \code{\link{write.df}}, \code{\link{write.df}},
  \code{\link{write.df}},
  \code{\link{write.df,SparkDataFrame-method}};
  \code{\link{schema}}, \code{\link{schema}},
  \code{\link{schema,SparkDataFrame-method}};
  \code{\link{selectExpr}}, \code{\link{selectExpr}},
  \code{\link{selectExpr,SparkDataFrame,character-method}};
  \code{\link{showDF}}, \code{\link{showDF}},
  \code{\link{showDF,SparkDataFrame-method}};
  \code{\link{show}}, \code{\link{show}},
  \code{\link{show,Column-method}},
  \code{\link{show,GroupedData-method}},
  \code{\link{show,SparkDataFrame-method}},
  \code{\link{show,WindowSpec-method}};
  \code{\link{storageLevel}},
  \code{\link{storageLevel,SparkDataFrame-method}};
  \code{\link{str}},
  \code{\link{str,SparkDataFrame-method}};
  \code{\link{take}}, \code{\link{take}},
  \code{\link{take,SparkDataFrame,numeric-method}};
  \code{\link{union}}, \code{\link{union}},
  \code{\link{union,SparkDataFrame,SparkDataFrame-method}},
  \code{\link{unionAll}}, \code{\link{unionAll}},
  \code{\link{unionAll,SparkDataFrame,SparkDataFrame-method}};
  \code{\link{unpersist}}, \code{\link{unpersist}},
  \code{\link{unpersist,SparkDataFrame-method}};
  \code{\link{withColumn}}, \code{\link{withColumn}},
  \code{\link{withColumn,SparkDataFrame,character-method}};
  \code{\link{with}},
  \code{\link{with,SparkDataFrame-method}};
  \code{\link{write.jdbc}}, \code{\link{write.jdbc}},
  \code{\link{write.jdbc,SparkDataFrame,character,character-method}};
  \code{\link{write.json}}, \code{\link{write.json}},
  \code{\link{write.json,SparkDataFrame,character-method}};
  \code{\link{write.orc}}, \code{\link{write.orc}},
  \code{\link{write.orc,SparkDataFrame,character-method}};
  \code{\link{write.text}}, \code{\link{write.text}},
  \code{\link{write.text,SparkDataFrame,character-method}}
}

